@@ -1,33 +1,37 @@
 from ._ilastik import (
-    list_ilastik_image_files,
-    list_ilastik_crop_files,
-    read_ilastik_image,
-    read_ilastik_crop,
-    write_ilastik_image,
-    write_ilastik_crop,
-    create_ilastik_image,
-    try_create_ilastik_images_from_disk,
-    create_ilastik_crop,
-    try_create_ilastik_crops_from_disk,
+    SteinbockIlastikClassificationException,
     create_and_save_ilastik_project,
-    run_pixel_classification,
-    try_fix_ilastik_crops_from_disk,
+    create_ilastik_crop,
+    create_ilastik_image,
     fix_ilastik_project_file_inplace,
+    list_ilastik_crop_files,
+    list_ilastik_image_files,
+    logger,
+    read_ilastik_crop,
+    read_ilastik_image,
+    run_pixel_classification,
+    try_create_ilastik_crops_from_disk,
+    try_create_ilastik_images_from_disk,
+    try_fix_ilastik_crops_from_disk,
+    write_ilastik_crop,
+    write_ilastik_image,
 )
 
 __all__ = [
-    "list_ilastik_image_files",
-    "list_ilastik_crop_files",
-    "read_ilastik_image",
-    "read_ilastik_crop",
-    "write_ilastik_image",
-    "write_ilastik_crop",
-    "create_ilastik_image",
-    "try_create_ilastik_images_from_disk",
-    "create_ilastik_crop",
-    "try_create_ilastik_crops_from_disk",
+    "SteinbockIlastikClassificationException",
     "create_and_save_ilastik_project",
-    "run_pixel_classification",
-    "try_fix_ilastik_crops_from_disk",
+    "create_ilastik_crop",
+    "create_ilastik_image",
     "fix_ilastik_project_file_inplace",
+    "list_ilastik_crop_files",
+    "list_ilastik_image_files",
+    "logger",
+    "read_ilastik_crop",
+    "read_ilastik_image",
+    "run_pixel_classification",
+    "try_create_ilastik_crops_from_disk",
+    "try_create_ilastik_images_from_disk",
+    "try_fix_ilastik_crops_from_disk",
+    "write_ilastik_crop",
+    "write_ilastik_image",
 ]
