@@ -69,15 +69,16 @@ def _clean_panel(panel: pd.DataFrame) -> pd.DataFrame:
     name_suffixes = panel.groupby("name").cumcount().map(lambda i: f" {i + 1}")
     panel.loc[name_dupl_mask, "name"] += name_suffixes[name_dupl_mask]
     if "keep" not in panel:
-        panel["keep"] = pd.Series(dtype=pd.BooleanDtype())
-        panel.loc[:, "keep"] = True
+        panel["keep"] = pd.Series([True] * len(panel.index), dtype=pd.BooleanDtype())
     if "ilastik" not in panel:
         panel["ilastik"] = pd.Series(dtype=pd.UInt8Dtype())
         panel.loc[panel["keep"], "ilastik"] = range(1, panel["keep"].sum() + 1)
     if "deepcell" not in panel:
         panel["deepcell"] = pd.Series(dtype=pd.UInt8Dtype())
+    if "cellpose" not in panel:
+        panel["cellpose"] = pd.Series(dtype=pd.UInt8Dtype())
     next_column_index = 0
-    for column in ("channel", "name", "keep", "ilastik", "deepcell"):
+    for column in ("channel", "name", "keep", "ilastik", "deepcell", "cellpose"):
         if column in panel:
             column_data = panel[column]
             panel.drop(columns=[column], inplace=True)
@@ -297,7 +298,7 @@ def _match_txt_file(
         logger.warning(
             "Ambiguous txt file matching for %s: %s; continuing without a match",
             mcd_file,
-            ", ".join(filtered_txt_files),
+            ", ".join(str(x) for x in filtered_txt_files),
         )
     return None
 
