@@ -1,6 +1,7 @@
 import click
 
 from ..._cli.utils import OrderedClickGroup
+from .cellpose import cellpose_cli_available, cellpose_cmd
 from .cellprofiler import cellprofiler_cmd_group
 from .deepcell import deepcell_cli_available, deepcell_cmd
 
@@ -17,3 +18,5 @@ def segment_cmd_group():
 segment_cmd_group.add_command(cellprofiler_cmd_group)
 if deepcell_cli_available:
     segment_cmd_group.add_command(deepcell_cmd)
+if cellpose_cli_available:
+    segment_cmd_group.add_command(cellpose_cmd)
