@@ -7,10 +7,10 @@ from pathlib import Path
 from typing import (
     TYPE_CHECKING,
     Any,
-    Callable,
     Generator,
     Mapping,
     Optional,
+    Protocol,
     Sequence,
     Tuple,
     Union,
@@ -67,17 +67,20 @@ def _mesmer_application(model=None):
 
 
 class Application(Enum):
-    """"""
-
     MESMER = partial(_mesmer_application)
 
 
+class AggregationFunction(Protocol):
+    def __call__(self, img: np.ndarray, axis: Optional[int] = None) -> np.ndarray:
+        ...
+
+
 def create_segmentation_stack(
     img: np.ndarray,
     channelwise_minmax: bool = False,
     channelwise_zscore: bool = False,
     channel_groups: Optional[np.ndarray] = None,
-    aggr_func: Callable[[np.ndarray], np.ndarray] = np.mean,
+    aggr_func: AggregationFunction = np.mean,
 ) -> np.ndarray:
     if channelwise_minmax:
         channel_mins = np.nanmin(img, axis=(1, 2))
@@ -110,7 +113,7 @@ def try_segment_objects(
     channelwise_minmax: bool = False,
     channelwise_zscore: bool = False,
     channel_groups: Optional[np.ndarray] = None,
-    aggr_func: Callable[[np.ndarray], np.ndarray] = np.mean,
+    aggr_func: AggregationFunction = np.mean,
     **predict_kwargs,
 ) -> Generator[Tuple[Path, np.ndarray], None, None]:
     app, predict = application.value(model=model)
@@ -123,8 +126,13 @@ def try_segment_objects(
                 channel_groups=channel_groups,
                 aggr_func=aggr_func,
             )
+            if img.shape[0] != 2:
+                raise SteinbockDeepcellSegmentationException(
+                    f"Invalid number of aggregated channels: "
+                    f"expected 2, got {img.shape[0]}"
+                )
             mask = predict(img, **predict_kwargs)
             yield Path(img_file), mask
             del img, mask
-        except:
-            logger.exception(f"Error segmenting objects in {img_file}")
+        except Exception as e:
+            logger.exception(f"Error segmenting objects in {img_file}: {e}")
